// Generic loongarch64 target for bare-metal code

use super::{LinkerFlavor, LldFlavor, CodeModel, PanicStrategy, RelocModel, Target, TargetOptions};

pub fn target() -> Target {
    let opts = TargetOptions {
        cpu: "la464".to_string(),
        max_atomic_width: Some(64),
        linker_flavor: LinkerFlavor::Lld(LldFlavor::Ld),
        linker: Some("rust-lld".to_owned()),
        // 2k500/1000 doesn't support unaligned loads/stores so we disable them with
        // -unaligned-access. 2k500 doesn't supoort lsx and lasx, 2k1000 only support lsx
        features: "-lsx,-lasx,-unaligned-access".to_string(),
        executables: true,
        code_model: Some(CodeModel::Medium),
        panic_strategy: PanicStrategy::Abort,
        relocation_model: RelocModel::Static,
        ..Default::default()
    };

    Target {
        llvm_target: "loongarch64-unknown-none".to_string(),
        pointer_width: 64,
        data_layout: "e-m:e-i8:8:32-i16:16:32-i64:64-n32:64-S128".to_string(),
        arch: "loongarch64".to_string(),
        options: opts,
    }
}
